import { WorkerActivityState } from '@/enums'
import { NullableProperties, Polygon, UUID } from '.'

/**
 * Statistics for all WorkerActivities within a corpus or a process.
 *
 * The aggregated processing times may all be defined as string representations of Python timedeltas,
 * or may all be null at once.
 */
export type WorkerActivityStats = {
  worker_version_id: UUID
  model_version_id: UUID | null
  configuration_id: UUID | null
} & {
  [State in WorkerActivityState]: number
} & NullableProperties<{
  average_processed_time: string
  min_processed_time: string
  max_processed_time: string
  median_processed_time: string
  completion_estimate_time: string
}>

interface ProcessElement {
  id: UUID
  type_id: UUID
  name: string
  confidence: number
  image_id: UUID
  image_width: number
  image_height: number
  image_url: string
  polygon: Polygon
  rotation_angle?: number
  mirrored?: boolean
}

/**
 * In the Process/Filter vue, the corpus ID is added to the response from ListProcessElements because
 * it is required by the ElementList component to display element types.
 */
export interface ProcessElementList extends ProcessElement {
  corpus: {
    id: UUID
  }
}
