import { RevisionWithRefs, UUID } from '@/types'
import { UserConfigurationField } from './workerConfiguration'
import { FeatureUsage, WorkerVersionState } from '@/enums'

export interface WorkerType {
  id: UUID
  slug: string
  display_name: string
}

export interface WorkerLight {
  id: UUID
  name: string
  type: string
  slug: string
}

export interface Worker extends WorkerLight {
  description: string
  repository_id: UUID
  archived: boolean
}

export function isWorker(worker: WorkerLight): worker is Worker {
  return ('repository_id' in worker && (worker.repository_id === null || typeof worker.repository_id === 'string'))
}

export type UserConfiguration = Record<string, UserConfigurationField>

interface WorkerVersionConfiguration {
  user_configuration?: UserConfiguration
  [key: string]: unknown
}

export type WorkerVersion = {
  id: UUID
  configuration: WorkerVersionConfiguration
  docker_image_name: string | null
  gpu_usage: FeatureUsage
  model_usage: FeatureUsage
  worker: WorkerLight
  created: string
} & ({
  state: WorkerVersionState
  docker_image: UUID | null
  docker_image_iid: string | null
} | {
  state: WorkerVersionState.Available
  docker_image: UUID
  docker_image_iid: string
}) & ({
  revision: null
  version: number
} | {
  revision: RevisionWithRefs
  version: null
})
