import { assert } from 'chai'
import { mutations, getters } from '@/store/tree.js'
import store from './index.spec.js'

describe('tree', () => {
  describe('mutations', () => {
    it('toggle', () => {
      const state = { toggledNodes: ['id1', 'id2', 'id3'] }
      mutations.toggle(state, 'id2')
      mutations.toggle(state, 'id5')
      assert.deepStrictEqual(state, {
        toggledNodes: ['id1', 'id3', 'id5']
      })
    })

    it('setTypeFilter', () => {
      const state = { typeFilter: '' }
      mutations.setTypeFilter(state, 'type_slug')
      assert.deepStrictEqual(state, { typeFilter: 'type_slug' })
      mutations.setTypeFilter(state, '')
      assert.deepStrictEqual(state, { typeFilter: '' })
    })
  })

  describe('getters', () => {
    afterEach(() => {
      store.reset()
    })

    describe('tree', () => {
      it('creates the tree for a given element', async () => {
        store.state.tree = { toggledNodes: ['id2', 'id4'] }
        const parent = { id: 'parentId', name: 'parent', type: 'folder' }
        store.state.elements = {
          elements: {
            parentId: parent,
            id1: { id: 'id1', name: 'child1', type: 'page' },
            id2: { id: 'id2', name: 'child2', type: 'page' },
            id3: { id: 'id3', name: 'child3', type: 'page' },
            id4: { id: 'id4', name: 'child4', type: 'page' },
            id21: { id: 'id21', name: 'child21', type: 'line' }
          },
          links: {
            parentId: { children: ['id1', 'id2', 'id3', 'id4'], parents: [] },
            id1: { children: [], parents: ['parentId'] },
            id2: { children: ['id21'], parents: ['parentId'] },
            id3: { children: [], parents: ['parentId'] },
            id4: { children: [], parents: ['parentId'] },
            id21: { children: [], parents: ['id2'] }
          }
        }
        assert.deepStrictEqual(
          getters.tree(store.state.tree, getters, store.state)(parent),
          {
            element: parent,
            expanded: true,
            children: [
              {
                element: store.state.elements.elements.id1,
                expanded: false,
                children: []
              }, {
                element: store.state.elements.elements.id2,
                expanded: true,
                children: [
                  {
                    element: store.state.elements.elements.id21,
                    expanded: false,
                    children: []
                  }
                ]
              }, {
                element: store.state.elements.elements.id3,
                expanded: false,
                children: []
              }, {
                element: store.state.elements.elements.id4,
                expanded: true,
                children: []
              }
            ]
          }
        )
      })
    })
  })
})
